
======================
Internal API reference
======================

.. currentmodule:: pyexcel.internal.sheets
.. _iapi:

This is intended for developers and hackers of pyexcel. 

Data sheet representation
=========================

In inheritance order from parent to child

.. autosummary::
   :toctree: iapi

   Matrix

.. currentmodule:: pyexcel.internal.generators

.. autosummary::
   :toctree: iapi

   SheetStream
   BookStream

.. currentmodule:: pyexcel.internal.sheets

Row representation
===================

.. autosummary::
   :toctree: iapi

   Row

Column representation
=====================

.. autosummary::
   :toctree: iapi

   Column
